@@ -211,6 +211,11 @@ static void e_webcal_open_cal (const gchar * uri) {
 static gboolean e_webcal_idle_callback (void * data) {
   GSList * p = (GSList *) data;
 
+  gtk_rc_parse_string ("style \"dialog-defaults\" {\n"
+		       "  GtkDialog::action-area-border = 12\n"
+		       "} widget_class \"GtkDialog\""
+		       " style \"dialog-defaults\"\n");
+
   if (p != NULL) {
     for (; p && p->data; p = p->next) {
       const gchar * uri = p->data;
